:github_url: https://github.com/adc-connect/adcc/blob/master/docs/zpublications.rst

Publications and references
===========================

This page holds a collection of publications related to adcc
and lists references and software used in the context of adcc.

We kindly ask all users of adcc, who find the package useful for their
research to cite the adcc paper :cite:`adcc` and the
`DOI of the adcc code <https://zenodo.org/badge/latestdoi/215731857>`_
in the version which was used for the calculation.

.. _publications:

adcc publications
-----------------

.. list-table::

   * - **Paper:**
     - .. image:: https://img.shields.io/badge/DOI-10.1002/wcms.1462-blue
          :target: https://doi.org/10.1002/wcms.1462

       .. image:: https://img.shields.io/badge/hal-preprint-red
          :target: https://hal.archives-ouvertes.fr/hal-02319517

   * - **Code:**
     - .. image:: https://zenodo.org/badge/215731857.svg
          :target: https://zenodo.org/badge/latestdoi/215731857

.. bibliography:: pub.bib
   :all:
   :style: unsrtalpha

Other references
----------------

.. bibliography:: ref.bib
   :style: alpha
